==> hadoop-client-api-3.2.4-sources.jar: org/apache/hadoop/hdfs/protocol/AclException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.shaded.org.apache.hadoop.hdfs.protocol;

import java.org.apache.hadoop.shaded.io.IOException;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;

/**
 * Indicates a failure manipulating an ACL.
 */
@InterfaceAudience.Private
public class AclException extends IOException {
  private static final long serialVersionUID = 1L;

  /**
   * Creates a new AclException.
   *
   * @param message String message
   */
  public AclException(String message) {
    super(message);
  }

  /**
   * Creates a new AclException.
   *
   * @param message String message
   * @param cause The cause of the exception
   */
  public AclException(String message, Throwable cause) {
    super(message, cause);
  }
}

==> hadoop-client-api-3.4.0-sources.jar: org/apache/hadoop/hdfs/protocol/AclException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.shaded.org.apache.hadoop.hdfs.protocol;

import java.io.IOException;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;

/**
 * Indicates a failure manipulating an ACL.
 */
@InterfaceAudience.Private
public class AclException extends IOException {
  private static final long serialVersionUID = 1L;

  /**
   * Creates a new AclException.
   *
   * @param message String message
   */
  public AclException(String message) {
    super(message);
  }

  /**
   * Creates a new AclException.
   *
   * @param message String message
   * @param cause The cause of the exception
   */
  public AclException(String message, Throwable cause) {
    super(message, cause);
  }
}
